@@ -36,7 +36,7 @@ ChatWidget::ChatWidget(QWidget* parent)
     
     m_chat->setFocusProxy(m_input);
     
-    m_history.push_back(QLatin1Literal(""));
+    m_history.push_back(QLatin1String(""));
     m_current = 0;
     
     connect(m_input, &QLineEdit::returnPressed, this, &ChatWidget::sendLine);
@@ -76,7 +76,7 @@ bool ChatWidget::eventFilter(QObject* obj, QEvent* event)
 void ChatWidget::sendLine()
 {
     QString text = m_input->text();
-    m_history.push_back(QLatin1Literal(""));
+    m_history.push_back(QLatin1String(""));
     setHistoryText(m_history.size() - 1);
     display(m_nick, text);
     emit message(text);
